@@ -2,7 +2,7 @@ use strict;
 package Config::Easy;
 use Carp qw/croak/;
 
-our $VERSION = "0.2";
+our $VERSION = "0.3";
 our %C;
 my ($fname, $fromfile, $atline, $expanded);
 use constant STRICT => " strict";        # key for strict_hash emulation
@@ -577,6 +577,6 @@ Date::Simple is an elegant way of dealing with dates.
 
 =head1 AUTHOR
 
-Jon Bjornstad <jon@icogitate.com>
+Jon Bjornstad <jonb@logicalpoetry.com>
 
 =cut
